@@ -41,9 +41,11 @@ do
 	$PSQL test <<EOF
 CREATE TABLE t1 (i int);
 CREATE TABLE black_t (i int);
+CREATE TABLE with_modify (i int);
+CREATE TABLE explain_analyze (i int);
 CREATE VIEW normal_v AS SELECT * FROM t1;
 CREATE VIEW white_v AS SELECT * FROM t1;
-
+SELECT pg_sleep(2);	-- Sleep for a while to make sure object creations are replicated
 SELECT * FROM t1;
 SELECT * FROM t1;
 SELECT * FROM black_t;
@@ -52,13 +54,31 @@ SELECT * FROM normal_v;
 SELECT * FROM normal_v;
 SELECT * FROM white_v;
 SELECT * FROM white_v;
+SELECT * FROM with_modify;
+WITH cte AS (INSERT INTO with_modify values(1) RETURNING *) SELECT * FROM with_modify;
+WITH cte AS (INSERT INTO with_modify values(1) RETURNING *) SELECT * FROM with_modify;
+SELECT * FROM with_modify;
+SELECT * FROM explain_analyze;
+EXPLAIN ANALYZE INSERT INTO explain_analyze VALUES(1);
+SELECT * FROM explain_analyze;
+SELECT CURRENT_TIMESTAMP;
+SELECT CURRENT_USER;
 EOF
 
-	grep "fetched from cache" log/pgpool.log | grep t1 > /dev/null || exit 1
-	grep "fetched from cache" log/pgpool.log | grep black_t > /dev/null && exit 1
-	grep "fetched from cache" log/pgpool.log | grep normal_v > /dev/null && exit 1
-	grep "fetched from cache" log/pgpool.log | grep white_v > /dev/null || exit 1
-
+	success=true
+	grep "fetched from cache" log/pgpool.log | grep t1 > /dev/null || success=false
+	grep "fetched from cache" log/pgpool.log | grep black_t > /dev/null && success=false
+	grep "fetched from cache" log/pgpool.log | grep normal_v > /dev/null && success=false
+	grep "fetched from cache" log/pgpool.log | grep white_v > /dev/null || success=false
+	grep "fetched from cache" log/pgpool.log | grep with_modify > /dev/null && success=false
+	grep "fetched from cache" log/pgpool.log | grep explain_analyze > /dev/null && success=false
+	grep "fetched from cache" log/pgpool.log | grep CURRENT_TIMESTAMP > /dev/null && success=false
+	grep "fetched from cache" log/pgpool.log | grep CURRENT_USER > /dev/null && success=false
+	if [ $success = false ];then
+		./shutdownall
+		exit 1
+	fi
+	    
 	java jdbctest > result.txt 2>&1
 	cmp ../expected.txt result.txt
 	if [ $? != 0 ];then
